@@ -1,30 +1,34 @@
-# Copyrights 2001-2017 by [Mark Overmeer].
+# Copyrights 2001-2018 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-use strict;
-use warnings;
+# This code is part of distribution Mail-Message.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Mail::Message;
 use vars '$VERSION';
-$VERSION = '3.003';
+$VERSION = '3.007';
 
 use base 'Mail::Reporter';
 
-use Mail::Message::Part;
-use Mail::Message::Head::Complete;
-use Mail::Message::Construct;
+use strict;
+use warnings;
 
-use Mail::Message::Body::Lines;
-use Mail::Message::Body::Multipart;
-use Mail::Message::Body::Nested;
+use Mail::Message::Part ();
+use Mail::Message::Head::Complete ();
+use Mail::Message::Construct ();
+
+use Mail::Message::Body::Lines ();
+use Mail::Message::Body::Multipart ();
+use Mail::Message::Body::Nested ();
 
 use Carp;
 use Scalar::Util   'weaken';
 
 BEGIN {
     unless($ENV{HARNESS_ACTIVE}) {   # no tests during upgrade
-        # v3 splits Mail::Box is many distributions
+        # v3 splits Mail::Box in a few distributions
 		eval { require Mail::Box };
 		my $v = $Mail::Box::VERSION || 3;
 		$v >= 3 or die "You need to upgrade the Mail::Box module";
@@ -161,6 +165,7 @@ my $default_mailer;
 sub send(@)
 {   my $self = shift;
 
+	# Loosely coupled module
     require Mail::Transport::Send;
 
     my $mailer;
