@@ -1,17 +1,21 @@
-# Copyrights 2001-2017 by [Mark Overmeer].
+# Copyrights 2001-2018 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-use strict;
-use warnings;
+# This code is part of distribution Mail-Message.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Mail::Message::Field::Full;
 use vars '$VERSION';
-$VERSION = '3.003';
+$VERSION = '3.007';
 
 use base 'Mail::Message::Field';
 
+use strict;
+use warnings;
 use utf8;
+
 use Encode ();
 use MIME::QuotedPrint ();
 use Storable 'dclone';
@@ -119,7 +123,10 @@ sub unfoldedBody($;$)
 
     $body = $self->foldedBody;
     $body =~ s/^ //;
-    $body =~ s/\n//g;
+
+	# remove FWS, also required within quoted strings.
+    $body =~ s/\r?\n\s?/ /g;
+    $body =~ s/ +$//;
     $body;
 }
 
