@@ -1,16 +1,20 @@
-# Copyrights 2001-2017 by [Mark Overmeer].
+# Copyrights 2001-2018 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-use strict;
-use warnings;
+# This code is part of distribution Mail-Message.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Mail::Message::Field::Structured;
 use vars '$VERSION';
-$VERSION = '3.003';
+$VERSION = '3.007';
 
 use base 'Mail::Message::Field::Full';
 
+use strict;
+use warnings;
+
 use Mail::Message::Field::Attribute;
 use Storable 'dclone';
 
@@ -65,7 +69,11 @@ sub attrPairs() { map +($_->name, $_->value), shift->attributes }
 
 sub parse($)
 {   my ($self, $string) = @_;
-    chomp $string;
+
+    # remove FWS, even within quoted strings
+    $string =~ s/\r?\n\s?/ /gs;
+	$string =~ s/ +$//;
+
     my $datum = '';
     while(length $string && substr($string, 0, 1) ne ';')
     {   (undef, $string)  = $self->consumeComment($string);
